CCL: Data Fields

CCL

Here is a list of all struct and union fields with links to the structures/unions they belong to:

### - a -

- A_s : ccl_parameters
- A_SPLINE_DELTA : ccl_spline_params
- A_SPLINE_MAX : ccl_spline_params
- A_SPLINE_MIN : ccl_spline_params
- A_SPLINE_NA : ccl_spline_params
- accelerator : ccl_data
- accelerator_achi : ccl_data
- accelerator_d : ccl_data
- accelerator_k : ccl_data
- accelerator_m : ccl_data
- achi : ccl_data
- alphab : eh_struct
- alphac : eh_struct
- alphahmf : ccl_data

### - b -

- betab : eh_struct
- betac : eh_struct
- betahmf : ccl_data
- bin_zmax_ : norm_params
- bin_zmin_ : norm_params
- bnode : eh_struct

### - c -

- chi : ccl_data , Fpar , IntLensPar , IntMagPar
- chimax : CCL_ClTracer
- chimin : CCL_ClTracer
- clt1 : IntClPar
- clt2 : IntClPar
- computed_distances : ccl_cosmology
- computed_growth : ccl_cosmology
- computed_hmfparams : ccl_cosmology
- computed_power : ccl_cosmology
- computed_sigma : ccl_cosmology
- config : ccl_cosmology
- cosmo : chipar , Fpar , IntClPar , IntLensPar , IntMagPar , SigmaR_pars

### - d -

- data : ccl_cosmology , ctest
- df_mgrowth : ccl_parameters
- dlnsigma_dlogm : ccl_data

### - e -

- E : ccl_data
- etahmf : ccl_data

### - f -

- fgrowth : ccl_data

### - g -

- gammahmf : ccl_data
- growth : ccl_data
- growth0 : ccl_data

### - h -

- h : ccl_parameters
- H0 : ccl_parameters
- has_intrinsic_alignment : CCL_ClTracer
- has_magnification : CCL_ClTracer
- has_mgrowth : ccl_parameters
- has_rsd : CCL_ClTracer

### - i -

- intacc : SplPar

### - k -

- K_MAX : ccl_spline_params
- K_MAX_SPLINE : ccl_spline_params
- k_min : ccl_data
- K_MIN_DEFAULT : ccl_spline_params
- k_sign : ccl_parameters
- keq : eh_struct
- kSilk : eh_struct

### - l -

- l : IntClPar
- LOGM_SPLINE_DELTA : ccl_spline_params
- LOGM_SPLINE_MAX : ccl_spline_params
- LOGM_SPLINE_MIN : ccl_spline_params
- LOGM_SPLINE_NM : ccl_spline_params
- logsigma : ccl_data

### - m -

- magic : ctest
- mass_function_method : ccl_configuration
- matter_power_spectrum_method : ccl_configuration
- mnu : ccl_parameters

### - n -

- N_A : ccl_spline_params
- N_K : ccl_spline_params
- N_nu_mass : ccl_parameters
- N_nu_rel : ccl_parameters
- n_s : ccl_parameters
- nz_mgrowth : ccl_parameters

### - o -

- Omega_b : ccl_parameters
- Omega_c : ccl_parameters
- Omega_g : ccl_parameters
- Omega_k : ccl_parameters
- Omega_l : ccl_parameters
- Omega_m : ccl_parameters
- Omega_n_mass : ccl_parameters
- Omega_n_rel : ccl_parameters

### - p -

- p_lin : ccl_data
- p_nl : ccl_data
- params : ccl_cosmology
- phihmf : ccl_data
- prefac_lensing : CCL_ClTracer

### - r -

- R : SigmaR_pars
- rsound : eh_struct
- rsound_approx : eh_struct
- run : ctest

### - s -

- setup : ctest
- sigma_8 : ccl_parameters
- sigma_z : user_func_params
- skip : ctest
- spl_ba : CCL_ClTracer
- spl_bz : CCL_ClTracer
- spl_nz : CCL_ClTracer
- spl_pz : IntLensPar , IntMagPar
- spl_rf : CCL_ClTracer
- spl_sz : CCL_ClTracer , IntMagPar
- spl_wL : CCL_ClTracer
- spl_wM : CCL_ClTracer
- spline : SplPar
- sqrtk : ccl_parameters
- ssname : ctest
- status : ccl_cosmology , chipar , Fpar , IntClPar , IntLensPar , IntMagPar , norm_params , pz_params , SigmaR_pars
- status_message : ccl_cosmology

### - t -

- T_CMB : ccl_parameters
- teardown : ctest
- th2p7 : eh_struct
- tracer_type : CCL_ClTracer
- transfer_function_method : ccl_configuration
- ttname : ctest
- type_ : dNdz_sources_params , norm_params

### - u -

- unnormedfunc : norm_params
- user_information : norm_params , pz_params

### - w -

- w0 : ccl_parameters
- wa : ccl_parameters

### - x -

- x0 : SplPar
- xf : SplPar

### - y -

- y0 : SplPar
- yf : SplPar
- your_pz_func : user_pz_info
- your_pz_params : user_pz_info

### - z -

- z_mgrowth : ccl_parameters
- z_star : ccl_parameters
- z_true : pz_params
- zdrag : eh_struct
- zeq : eh_struct